@@ -33,7 +33,8 @@ class Parameter():
             'param_form': self.param_form
         }
 
-    def verification(self, checking: dict, verify: dict, optional: dict = {}, null_value: bool = False) -> dict:
+    @classmethod
+    def verification(checking: dict, verify: dict, optional: dict = {}, null_value: bool = False) -> dict:
         for opt_k, opt_v in optional.items():
             # 没有选填参数时，填充预设的默认值
             if not checking.__contains__(opt_k):
@@ -42,8 +43,9 @@ class Parameter():
             json_data = {'All Parameters': {}, 'Optional': optional}
             for k, v in verify.items():
                 json_data['All Parameters'][k] = str(v)
-            logging.warning('请求参数不完整: {0}'.format(json.dumps(json_data)))
-            abort(Response(json.dumps(json_data), 400, {}))
+            str_data = '请求参数不完整: {0}'.format(json.dumps(json_data))
+            logging.warning(str_data)
+            abort(Response(str_data, 400, {}))
         for _k, _v in checking.items():
             try:
                 str_data = None
@@ -53,7 +55,8 @@ class Parameter():
                     if not _v.strip():
                         str_data = f'参数 {_k} 不能是空字符串'
                 if str_data:
-                    logging.warning('请求参数类型校验失败: {0}'.format(str_data))
+                    str_data = '请求参数类型校验失败: {0}'.format(str_data)
+                    logging.warning(str_data)
                     abort(Response(str_data, 400, {}))
             except KeyError as err:
                 str_data = f'有多余的请求参数: {err}'
