@@ -22,3 +22,16 @@ def handle_date(date: str, date_type='start') -> datetime:
         date_data = None
         logging.warning('日期字符串解析异常: {0}'.format(err))
     return date_data
+
+
+def handle_db_to_list(db_list: list) -> list:
+    """
+    将db列表数据，转换为list（原db的id是ObjectId类型，转为json会报错）
+    :param db_list:db列表数据（find()获取）
+    :return:转换后的列表
+    """
+    if not isinstance(db_list, list):
+        raise TypeError("a %s is required (got type %s)" % (list, type(db_list)))
+    for db in db_list:
+        db['_id'] = str(db['_id'])
+    return db_list
